Struct ipfs_sqlite_block_store::SizeTargets [−][src]
Size targets for a store. Gc of non-pinned blocks will start once one of the size targets is exceeded.
There are targets for both block count and block size. The reason for this is that a store that has a very large number of tiny blocks will become sluggish despite not having a large total size.
Size targets only apply to non-pinned blocks. Pinned blocks will never be gced even if exceeding one of the size targets.
Fields
count: u64target number of blocks.
Up to this number, the store will retain everything even if not pinned. Once this number is exceeded, the store will run garbage collection of all unpinned blocks until the block criterion is met again.
To completely disable storing of non-pinned blocks, set this to 0. Even then, the store will never delete pinned blocks.
size: u64target store size.
Up to this size, the store will retain everything even if not pinned. Once this size is exceeded, the store will run garbage collection of all unpinned blocks until the size criterion is met again.
The store will never delete pinned blocks.
Implementations